-- ScroogeDecisions
-- Author: RoxyRiku94 (original Civilization by CleverAdvisor)
-- DateCreated: 12/19/2016 2:01:53 PM
--------------------------------------------------------------

print("Duckburg Decisions: loaded")

--=======================================================================================================================
-- UTILITIES
--=======================================================================================================================
-- Globals
-------------------------------------------------------------------------------------------------------------------------
local mathCeil				= math.ceil
local techGuildsID			= GameInfoTypes["TECH_GUILDS"]
local techGunpowderID		= GameInfoTypes["TECH_GUNPOWDER"]	
local techRefrigerationID 	= GameInfoTypes["TECH_REFRIGERATION"]
local SCROOGE_ITC_POLICY 	= GameInfoTypes.POLICY_DECISIONS_SCROOGE_ITC
local SCROOGE_GASTRAPHETES_POLICY = GameInfoTypes.POLICY_DECISIONS_SCROOGE_GASTRAPHETES
local SCROOGE_ITC_BUILDING 	= GameInfoTypes.BUILDING_DECISIONS_SCROOGE_ITC
local SCROOGE_ICE_CREAM		= GameInfoTypes.BUILDING_DECISIONS_SCROOGE_ICE_CREAM_DUMMY
--------------------------------------------------------------------------------------------------------------------------------------------
--Decision 1: Construct the Gastraphetes Bowgun
--------------------------------------------------------------------------------------------------------------------------------------------

local Decisions_ScroogeGastraphetes = {}
    Decisions_ScroogeGastraphetes.Name = "TXT_KEY_DECISIONS_SCROOGE_GASTRAPHETES"
	Decisions_ScroogeGastraphetes.Desc = Locale.ConvertTextKey("TXT_KEY_DECISIONS_SCROOGE_GASTRAPHETES_DESC")
	HookDecisionCivilizationIcon(Decisions_ScroogeGastraphetes, "CIVILIZATION_DUCK")
	Decisions_ScroogeGastraphetes.CanFunc = (
	function(pPlayer)
		if pPlayer:GetCivilizationType() ~= GameInfoTypes.CIVILIZATION_DUCK then return false, false end
		if load(pPlayer, "Decisions_ScroogeGastraphetes") == true then
			Decisions_ScroogeGastraphetes.Desc = Locale.ConvertTextKey("TXT_KEY_DECISIONS_SCROOGE_GASTRAPHETES_ENACTED_DESC")
			return false, false, true
		end
		
		Decisions_ScroogeGastraphetes.tCompositeBowman = {}
		for pUnit in pPlayer:Units() do
			if pUnit:GetUnitType() == GameInfoTypes.UNIT_COMPOSITE_BOWMAN then table.insert(Decisions_ScroogeGastraphetes.tCompositeBowman, pUnit) end
		end

		local iNum = #Decisions_ScroogeGastraphetes.tCompositeBowman
		local iGoldCost = math.ceil(300 + (60 * iMod * iNum))
		local iMagistrateCost = 1
		
		Decisions_ScroogeGastraphetes.Desc = Locale.ConvertTextKey("TXT_KEY_DECISIONS_SCROOGE_GASTRAPHETES_DESC", iGoldCost, iMagistrateCost)
		
		if iNum < 5 then return true, false end
		if (pPlayer:GetGold() < iGoldCost) then	return true, false end
		if (pPlayer:GetNumResourceAvailable(iMagistrate, false) < iMagistrateCost) then return true, false end
		if (not Teams[player:GetTeam()]:IsHasTech(techGunpowderID))	then return true, false end
		
		local bHasConquered = false
		local iPlayer = pPlayer:GetID()
		for pCity in pPlayer:Cities() do
			if ((pCity:GetOriginalOwner() ~= iPlayer)) then bHasConquered = true end
		end
		if not(bHasConquered) then return true, false end 
		
		return true, true
	end
	)
	
	Decisions_ScroogeGastraphetes.DoFunc = (
	function(pPlayer)
		local iNum = #Decisions_ScroogeGastraphetes.tCompositeBowman
		local iGoldCost = math.ceil(300 + (60 * iMod * iNum))
		local iPromotion = GameInfoTypes.PROMOTION_INDIRECT_FIRE
		local iMagistrateCost = 1
		pPlayer:ChangeGold(-iGoldCost)
		pPlayer:ChangeNumResourceTotal(iMagistrate, -iMagistrateCost)
		pPlayer:SetNumFreePolicies(1)
		pPlayer:SetNumFreePolicies(0)
		pPlayer:SetHasPolicy(SCROOGE_GASTRAPHETES_POLICY, true)
		for iKey, pUnit in ipairs(Decisions_ScroogeGastraphetes.tCompositeBowman) do
		local pNewUnit = pPlayer:InitUnit(GameInfoTypes.UNIT_KNIGHTSLAYER, pUnit:GetX(), pUnit:GetY())
		pNewUnit:Convert(pUnit)
		pNewUnit:SetHasPromotion(iPromotion, true)
		end
		save(pPlayer, "Decisions_ScroogeGastraphetes", true)
	end
	)
	
Decisions_AddCivilisationSpecific(GameInfoTypes.CIVILIZATION_DUCK, "Decisions_ScroogeGastraphetes", Decisions_ScroogeGastraphetes)
--------------------------------------------------------------------------------------------------------------------------------------------
--Decision 2: Establish the Duckburg International Trade Company
--------------------------------------------------------------------------------------------------------------------------------------------

local Decisions_ScroogeITC = {}
	Decisions_ScroogeITC.Name = "TXT_KEY_DECISIONS_SCROOGE_ITC"
	Decisions_ScroogeITC.Desc = Locale.ConvertTextKey("TXT_KEY_DECISIONS_SCROOGE_ITC_DESC")
	HookDecisionCivilizationIcon(Decisions_ScroogeITC, "CIVILIZATION_DUCK")
	Decisions_ScroogeITC.CanFunc = (
	function(pPlayer)
		if (pPlayer:GetCivilizationType() ~= GameInfoTypes.CIVILIZATION_DUCK) then return false, false end

		if load(pPlayer, "Decisions_ScroogeITC") == true then
			Decisions_ScroogeITC.Desc = Locale.ConvertTextKey("TXT_KEY_DECISIONS_SCROOGE_ITC_ENACTED_DESC")
			return false, false, true
		end
		
		local pCity = pPlayer:GetCapitalCity()
		local iMagistrateCost = 3
		Decisions_ScroogeITC.Desc = Locale.ConvertTextKey("TXT_KEY_DECISIONS_SCROOGE_ITC_DESC", iMagistrateCost)
	
		if pCity == nil then
			return true, false
		end
		if (pPlayer:GetNumResourceAvailable(iMagistrate, false) < iMagistrateCost) then return true, false end
		if (not Teams[player:GetTeam()]:IsHasTech(techGuildsID))	then return true, false end
		
		pScroogeITCUnit = nil
		local pPlot = pCity:Plot()
		local iNumUnits = pPlot:GetNumUnits()
		for iVal = 0,(iNumUnits - 1) do
			local pUnit = pPlot:GetUnit(iVal)
			local iUnitClass = pUnit:GetUnitClassType()
			if (pUnit:GetUnitClassType() == GameInfoTypes.UNITCLASS_GREAT_GENERAL) then
				pScroogeITCUnit = pUnit
				break
			end
		end
		if pScroogeITCUnit ~= nil then
			return true, true
		else
			return true, false
		end
	end
	)
	
	Decisions_ScroogeITC.DoFunc = (
	function(pPlayer)
		pScroogeITCUnit:Kill()
		local pCity = pPlayer:GetCapitalCity()
		if pCity then
			local iMagistrateCost = 3
			pPlayer:ChangeNumResourceTotal(iMagistrate, -iMagistrateCost)
			pCity:SetNumRealBuilding(SCROOGE_ITC_BUILDING, true)
			pPlayer:SetNumFreePolicies(1)
			pPlayer:SetNumFreePolicies(0)
			pPlayer:SetHasPolicy(SCROOGE_ITC_POLICY, true)
			end
		save(pPlayer, "Decisions_ScroogeITC", true)
	end
	)

Decisions_AddCivilisationSpecific(GameInfoTypes.CIVILIZATION_DUCK, "Decisions_ScroogeITC", Decisions_ScroogeITC)
--------------------------------------------------------------------------------------------------------------------------------------------
--Decision 3: Invent Duckburg's Fine Ice Cream
--------------------------------------------------------------------------------------------------------------------------------------------

local Decisions_ScroogeIceCream = {}
	Decisions_ScroogeIceCream.Name = "TXT_KEY_DECISIONS_SCROOGE_ICE_CREAM"
	Decisions_ScroogeIceCream.Desc = Locale.ConvertTextKey("TXT_KEY_DECISIONS_SCROOGE_ICE_CREAM_DESC")
	HookDecisionCivilizationIcon(Decisions_ScroogeIceCream, "CIVILIZATION_DUCK")
	Decisions_ScroogeIceCream.CanFunc = (
	function(pPlayer)
		if (pPlayer:GetCivilizationType() ~= GameInfoTypes.CIVILIZATION_DUCK) then
			return false, false
		end

		if load(pPlayer, "Decisions_ScroogeIceCream") then
			Decisions_ScroogeITC.Desc = Locale.ConvertTextKey("TXT_KEY_DECISIONS_SCROOGE_ICE_CREAM_ENACTED_DESC")
			return false, false, true
		end

		local pCity = pPlayer:GetCapitalCity()
		local iGoldCost = math.ceil(750 * iMod)
		local iMagistrateCost = 2

		Decisions_ScroogeITC.Desc = Locale.ConvertTextKey("TXT_KEY_DECISIONS_SCROOGE_ICE_CREAM_DESC", iGoldCost, iMagistrateCost)

		if pCity == nil then return true, false end
		if not(pCity:IsHasBuilding(GameInfoTypes.BUILDING_FACTORY)) then return true, false end
		if (pPlayer:GetNumResourceAvailable(iMagistrate, false) < iMagistrateCost) then return true, false end
		if (not Teams[player:GetTeam()]:IsHasTech(techRefrigerationID))	then return true, false end
		return true, true
	end
	)

	Decisions_ScroogeIceCream.DoFunc = (
	function(pPlayer)
		local iGoldCost = math.ceil(750 * iMod)
		local iMagistrateCost = 2
		pPlayer:ChangeGold(-iGoldCost)
		pPlayer:ChangeNumResourceTotal(iMagistrate, -iMagistrateCost)
		pPlayer:GetCapitalCity():SetNumRealBuilding(SCROOGE_ICE_CREAM, true)

		save(pPlayer, "Decisions_ScroogeIceCream", true)
	end
	)

	Decisions_AddCivilisationSpecific(GameInfoTypes.CIVILIZATION_DUCK, "Decisions_ScroogeIceCream", Decisions_ScroogeIceCream)